<?php
/**
 * SkeletonCart
 * (c) 2017 Juxtaposition Inc. All Rights Reserved.
 * (c) 2017 Curlybracket, Inc. All Rights Reserved.
 * This code cannot be redistributed without permission from the copyright holder.
 * For more information, consult your SkeletonCart license.
 **/

namespace WPDBConnector;

use App\Util;

class Plugin extends \App\Plugin
{
    protected $fileName;
    protected $config;

    public function __construct($key)
    {
        parent::__construct($key);
        $this->fileName = __DIR__ . '/Config.php';
        $this->loadConfig();
        $this->initCallback();
    }

    public function loadConfig()
    {
        if (!is_readable($this->fileName)) {
            throw new \RuntimeException("WPDBConnector設定が読み込めません。");
        }
        $this->config = include $this->fileName;

        $wpDBConfig = array(
            'DB_NAME',
            'DB_USER',
            'DB_PASSWORD',
            'DB_HOST',
            'DB_CHARSET',
        );
        foreach ($wpDBConfig as $name) {
            if (Util::is_empty($this->config[$name])) {
                throw new \RuntimeException("{$name}が設定されていません。");
            }
        }

        if (!isset($this->config['dataSource'])) {
            throw new \RuntimeException('dataSourceが設定されていません。');
        }
        $keys = array('itemId', 'itemName', 'itemPrice', 'itemGroupId', 'itemStock', 'itemWeight');
        foreach ($keys as $key) {
            if (!isset($this->config['itemId']) || strpos($this->config['itemId'], ':') === false) {
                throw new \RuntimeException("{$key}が設定されていません。");
            }
            list($post_type, $column) = explode(':', $this->config[$key]);
            if (empty($post_type) || empty($column)) {
                throw new \RuntimeException("{$key}の設定が不正な値です。");
            }
        }
    }

    public function initCallback()
    {
        \App::addCallback('postInit', array($this, 'postInit'));
    }

    public function postInit()
    {
        \App::register('itemList', function () {
            $itemList = new WPDBItemList($this->config);
            return $itemList;
        });
    }

}

\App::addPlugin(new Plugin('WPDBConnector'));

